# Generated by roxygen2: do not edit by hand

export("%>%")
export(analyze_document_clustering)
export(analyze_semantic_evolution)
export(analyze_sentiment)
export(analyze_sentiment_llm)
export(analyze_similarity_gaps)
export(assess_embedding_stability)
export(auto_tune_embedding_topics)
export(calculate_assignment_consistency)
export(calculate_clustering_metrics)
export(calculate_cosine_similarity)
export(calculate_cross_similarity)
export(calculate_dispersion_metrics)
export(calculate_document_similarity)
export(calculate_keyword_stability)
export(calculate_lexical_dispersion)
export(calculate_log_odds_ratio)
export(calculate_semantic_drift)
export(calculate_similarity_robust)
export(calculate_text_readability)
export(calculate_topic_probability)
export(calculate_topic_stability)
export(calculate_weighted_log_odds)
export(calculate_word_frequency)
export(call_llm_api)
export(check_python_env)
export(check_vision_models)
export(clear_lexdiv_cache)
export(cluster_embeddings)
export(describe_image)
export(detect_multi_words)
export(detect_pdf_content_type)
export(detect_pdf_content_type_py)
export(export_document_clustering)
export(extract_cross_category_similarities)
export(extract_keywords_keyness)
export(extract_keywords_tfidf)
export(extract_morphology)
export(extract_named_entities)
export(extract_noun_chunks)
export(extract_pos_tags)
export(extract_subjects_objects)
export(extract_tables_from_pdf_py)
export(extract_topic_terms_df)
export(find_optimal_k)
export(find_similar_words)
export(find_topic_matches)
export(fit_embedding_model)
export(fit_embedding_topics)
export(fit_semantic_model)
export(fit_temporal_model)
export(generate_cluster_labels)
export(generate_cluster_labels_auto)
export(generate_embeddings)
export(generate_topic_content)
export(generate_topic_labels)
export(get_available_dfm)
export(get_available_tokens)
export(get_best_embeddings)
export(get_content_type_prompt)
export(get_content_type_user_template)
export(get_sentences)
export(get_sentiment_color)
export(get_sentiment_colors)
export(get_spacy_model_info)
export(get_topic_prevalence)
export(get_topic_terms)
export(get_topic_texts)
export(get_word_similarity)
export(identify_topic_trends)
export(import_files)
export(init_spacy_nlp)
export(lemmatize_tokens)
export(lexical_diversity_analysis)
export(lexical_frequency_analysis)
export(plot_cluster_terms)
export(plot_cross_category_heatmap)
export(plot_document_sentiment_trajectory)
export(plot_emotion_radar)
export(plot_entity_frequencies)
export(plot_keyness_keywords)
export(plot_keyword_comparison)
export(plot_lexical_dispersion)
export(plot_lexical_diversity_distribution)
export(plot_log_odds_ratio)
export(plot_model_comparison)
export(plot_morphology_feature)
export(plot_mwe_frequency)
export(plot_ngram_frequency)
export(plot_pos_frequencies)
export(plot_quality_metrics)
export(plot_readability_by_group)
export(plot_readability_distribution)
export(plot_semantic_viz)
export(plot_sentiment_boxplot)
export(plot_sentiment_by_category)
export(plot_sentiment_distribution)
export(plot_sentiment_violin)
export(plot_similarity_heatmap)
export(plot_term_trends_continuous)
export(plot_tfidf_keywords)
export(plot_top_readability_documents)
export(plot_topic_effects_categorical)
export(plot_topic_effects_continuous)
export(plot_topic_probability)
export(plot_weighted_log_odds)
export(plot_word_frequency)
export(plot_word_probability)
export(prep_texts)
export(process_pdf_unified)
export(reduce_dimensions)
export(render_displacy_dep)
export(render_displacy_ent)
export(run_app)
export(run_neural_topics_internal)
export(run_rag_search)
export(run_text_workflow)
export(semantic_document_clustering)
export(semantic_similarity_analysis)
export(sentiment_embedding_analysis)
export(sentiment_lexicon_analysis)
export(setup_python_env)
export(show_web_banner)
export(spacy_extract_entities)
export(spacy_has_vectors)
export(spacy_initialized)
export(spacy_lemmatize)
export(spacy_parse_full)
export(summarize_morphology)
export(unite_cols)
export(validate_cross_models)
export(validate_semantic_coherence)
export(word_co_occurrence_network)
export(word_correlation_network)
import(dplyr)
import(ggplot2)
import(quanteda)
import(shiny)
import(tidyr)
importFrom(DT,datatable)
importFrom(DT,formatStyle)
importFrom(Matrix,colSums)
importFrom(RColorBrewer,brewer.pal)
importFrom(dplyr,arrange)
importFrom(dplyr,case_when)
importFrom(dplyr,count)
importFrom(dplyr,desc)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,group_map)
importFrom(dplyr,inner_join)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n_distinct)
importFrom(dplyr,pull)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_size_identity)
importFrom(ggplot2,theme_void)
importFrom(grDevices,colorRampPalette)
importFrom(htmltools,browsable)
importFrom(htmltools,tagList)
importFrom(htmltools,tags)
importFrom(igraph,V)
importFrom(igraph,assortativity_degree)
importFrom(igraph,betweenness)
importFrom(igraph,closeness)
importFrom(igraph,cluster_leiden)
importFrom(igraph,cluster_louvain)
importFrom(igraph,degree)
importFrom(igraph,diameter)
importFrom(igraph,distances)
importFrom(igraph,ecount)
importFrom(igraph,edge_density)
importFrom(igraph,eigen_centrality)
importFrom(igraph,graph_from_data_frame)
importFrom(igraph,induced_subgraph)
importFrom(igraph,layout_with_fr)
importFrom(igraph,modularity)
importFrom(igraph,transitivity)
importFrom(igraph,vcount)
importFrom(magrittr,"%>%")
importFrom(methods,as)
importFrom(quanteda,corpus)
importFrom(quanteda,dfm)
importFrom(quanteda,docnames)
importFrom(quanteda,tokens)
importFrom(quanteda.textstats,textstat_lexdiv)
importFrom(quanteda.textstats,textstat_readability)
importFrom(rlang,"%||%")
importFrom(rlang,sym)
importFrom(scales,rescale)
importFrom(shiny,showNotification)
importFrom(stats,as.dist)
importFrom(stats,as.formula)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,cutree)
importFrom(stats,dist)
importFrom(stats,glm)
importFrom(stats,glm.control)
importFrom(stats,hclust)
importFrom(stats,kmeans)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,poisson)
importFrom(stats,quantile)
importFrom(stats,reformulate)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,var)
importFrom(stats,vcov)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidytext,get_sentiments)
importFrom(tidytext,tidy)
importFrom(utils,head)
importFrom(utils,modifyList)
importFrom(utils,read.csv)
importFrom(utils,str)
importFrom(widyr,pairwise_cor)
importFrom(widyr,pairwise_count)
importFrom(widyr,pairwise_pmi)
