#' Special education technology bibliographic data
#'
#' Contains bibliographic data of journal articles and dissertations on the use of technology in teaching mathematics to students with disabilities.
#'
#' @source Bibliographic records compiled and coded by the author for
#'   Shin, M., Ok, M. W., Choo, S., Hossain, G., Bryant, D. P., & Kang, E.
#'   (2023). A content analysis of research on technology use for teaching
#'   mathematics to students with disabilities: Word networks and topic
#'   modeling. \emph{International Journal of STEM Education}, 10, Article 23.
#'   \doi{10.1186/s40594-023-00414-x}. Shared as open data at
#'   \url{https://github.com/mshin77/math-tech-sped}.
#'
#' @examples
#' SpecialEduTech
#'
"SpecialEduTech"

#' An example structure of a structural topic model
#'
#' Contains 15 topics, topic prevalences, and etc. from \code{stm::stm}.
#'
#' @examples
#' \donttest{
#' stm_15
#' }
"stm_15"

#' Acronym List
#'
#' A dataset containing common acronyms used in text processing
#'
#' @format A character vector of acronyms
#' @name acronym
#' @docType data
#' @keywords datasets
NULL

#' Stopwords List
#'
#' A dataset containing stopwords for text preprocessing
#'
#' @format A character vector of stopwords
#' @name stopwords_list
#' @docType data
#' @keywords datasets
NULL
