---
title: "Getting Started"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Getting Started}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(message = FALSE, warning = FALSE)
```

TextAnalysisR provides text analysis through an interactive Shiny app or R code.

## Install

```{r, eval = FALSE}
install.packages("TextAnalysisR",
  repos = c("https://mshin77.r-universe.dev", "https://cloud.r-project.org"))
```

## Launch App

```{r, eval = FALSE}
library(TextAnalysisR)
run_app()
```

Or visit [textanalysisr.org](https://www.textanalysisr.org) for the web version.

## Quick Example

```{r}
library(TextAnalysisR)

mydata <- SpecialEduTech
united_tbl <- unite_cols(mydata, listed_vars = c("title", "keyword", "abstract"))

tokens <- prep_texts(united_tbl, text_field = "united_texts")
dfm_object <- quanteda::dfm(tokens)

plot_word_frequency(dfm_object, n = 20)
```

## Features

| Category | Analyses |
|----------|----------|
| Lexical | Word frequency, keywords, networks |
| Semantic | Similarity, clustering, sentiment |
| Topic Modeling | STM and BERTopic |

