## Author

Mikyung Shin, Ph.D.\
Assistant Professor, Department of Special Education \
Illinois State University

## Contact

- Email: [mshin2@ilstu.edu](mailto:mshin2@ilstu.edu)
- GitHub: [github.com/mshin77](https://github.com/mshin77)
- Homepage: [mshin77.net](https://mshin77.net/)

## Selected Publications

Shin, M., Deniz, F., Watson, L., Dieterich, C., Ewoldt, K., Johnson, F., Kong, J., Lee, S. H., & Whitehurst, A. (2026). Addressing the void of AI policies in education for students with specific learning disabilities. *Learning Disability Quarterly, 49*(3), 134-146. [DOI](https://doi.org/10.1177/07319487251412879)

Shin, M., Park, H., & Kang, E. (2025). Development of education policies and practices for students with learning disabilities in South Korea using Delphi surveys and topic modeling. *Learning Disability Quarterly, 48*(1), 13-25. [DOI](https://doi.org/10.1177/07319487241280393)

Shin, M., Ok, M. W., Choo, S., Hossain, G., Bryant, D. P., & Kang, E. (2023). A content analysis of research on technology use for teaching mathematics to students with disabilities: Word networks and topic modeling. *International Journal of STEM Education, 10*, Article 23. [DOI](https://doi.org/10.1186/s40594-023-00414-x)
