## Documentation

- [R Package Documentation](https://mshin77.github.io/TextAnalysisR/)
- [GitHub Repository](https://github.com/mshin77/TextAnalysisR)
- [BERTopic Documentation](https://maartengr.github.io/BERTopic/)
- [Sentence Transformers](https://www.sbert.net/)

## Applications

- **R Package** (full features): `install.packages("TextAnalysisR", repos = c("https://mshin77.r-universe.dev", "https://cloud.r-project.org"))`
- **Web App** (core features): [textanalysisr.org](https://www.textanalysisr.org)

## Use Policy

- Academic, research, and non-commercial use only
- Third-party services restricted to non-commercial purposes under GPL-3 license

## Support

- [GitHub Issues](https://github.com/mshin77/TextAnalysisR/issues)
- [Documentation](https://mshin77.github.io/TextAnalysisR)
