% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/topic_modeling.R
\name{get_content_type_prompt}
\alias{get_content_type_prompt}
\title{Get Default System Prompt for Content Type}
\usage{
get_content_type_prompt(content_type)
}
\arguments{
\item{content_type}{Type of content to generate.}
}
\value{
Character string with the system prompt.
}
\description{
Returns the default system prompt for a given content type.
}
\concept{ai}
