% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/TextAnalysisR-package.R
\docType{package}
\name{TextAnalysisR-package}
\alias{TextAnalysisR}
\alias{TextAnalysisR-package}
\title{TextAnalysisR: A Text Mining Workflow Tool}
\description{
\if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}

Provides a text mining and natural language processing workflow for documents. Includes preprocessing via 'quanteda', lexical analysis (term frequency-inverse document frequency, log-odds ratios, lexical diversity) via 'tidytext', topic modeling via 'stm' and the 'BERTopic' approach, semantic similarity and document clustering on transformer representations, an interactive 'Shiny' interface with 'ggplot2' visualization, optional 'spaCy' preprocessing, and local 'sentence-transformers' or web-based ('OpenAI', 'Gemini') model providers for retrieval-augmented generation, as described in Shin et al. (2026) \doi{10.1177/07319487251412879}.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://mshin77.github.io/TextAnalysisR/}
  \item \url{https://github.com/mshin77/TextAnalysisR}
  \item Report bugs at \url{https://github.com/mshin77/TextAnalysisR/issues}
}

}
\author{
\strong{Maintainer}: Mikyung Shin \email{shin.mikyung@gmail.com} (\href{https://orcid.org/0000-0001-7907-9193}{ORCID})

Authors:
\itemize{
  \item Mikyung Shin \email{shin.mikyung@gmail.com} (\href{https://orcid.org/0000-0001-7907-9193}{ORCID})
}

}
\keyword{internal}
