% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/topic_modeling.R
\name{calculate_coherence}
\alias{calculate_coherence}
\title{Validate Semantic Coherence}
\usage{
calculate_coherence(embeddings, topic_assignments)
}
\arguments{
\item{embeddings}{Document embeddings.}

\item{topic_assignments}{Topic assignments.}
}
\value{
Coherence metrics.
}
\description{
Validates semantic coherence of topic assignments.
}
\keyword{internal}
