% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{get_sentiment_colors}
\alias{get_sentiment_colors}
\title{Get Sentiment Color Palette}
\usage{
get_sentiment_colors()
}
\value{
Named vector of colors
}
\description{
Returns standardized color mapping for sentiment analysis.
}
\concept{visualization}
\keyword{internal}
