% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{apply_standard_plotly_layout}
\alias{apply_standard_plotly_layout}
\title{Apply Standard Plotly Layout}
\usage{
apply_standard_plotly_layout(
  plot,
  title = NULL,
  xaxis_title = NULL,
  yaxis_title = NULL,
  margin = list(t = 60, b = 80, l = 80, r = 40),
  show_legend = FALSE
)
}
\arguments{
\item{plot}{A plotly plot object}

\item{title}{Plot title text (optional)}

\item{xaxis_title}{X-axis title (optional)}

\item{yaxis_title}{Y-axis title (optional)}

\item{margin}{List of margins: list(t, b, l, r) in pixels (default: list(t = 60, b = 80, l = 80, r = 40))}

\item{show_legend}{Logical, whether to show legend (default: FALSE)}
}
\value{
A plotly plot object with standardized layout
}
\description{
Applies consistent layout styling to plotly plots following TextAnalysisR design standards.
This ensures all plots have uniform fonts, colors, margins, and interactive features.
}
\details{
Design standards applied:
\itemize{
\item Title: 14px Roboto, #0c1f4a
\item Axis titles: 13px Roboto, #0c1f4a
\item Axis tick labels: 12px Roboto, #3B3B3B
}
}
\keyword{internal}
