% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{show_preprocessing_steps_modal}
\alias{show_preprocessing_steps_modal}
\title{Show preprocessing-steps modal}
\usage{
show_preprocessing_steps_modal(
  title = "Preprocessing Required",
  message,
  required_steps,
  optional_steps = NULL,
  additional_note = NULL
)
}
\arguments{
\item{title}{Modal title.}

\item{message}{Lead message.}

\item{required_steps}{Character vector of required step labels.}

\item{optional_steps}{Character vector of optional step labels.}

\item{additional_note}{Optional note appended to the body.}
}
\value{
Invisibly \code{NULL}.
}
\description{
Show preprocessing-steps modal
}
\keyword{internal}
