% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{show_warning_notification}
\alias{show_warning_notification}
\title{Show warning notification}
\usage{
show_warning_notification(message, duration = 5, session = NULL)
}
\arguments{
\item{message}{Notification text.}

\item{duration}{Seconds until auto-dismiss.}

\item{session}{Shiny session. Defaults to the current reactive domain.}
}
\value{
Invisibly the notification id.
}
\description{
Show warning notification
}
\keyword{internal}
