% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{get_plotly_hover_config}
\alias{get_plotly_hover_config}
\title{Plotly hover tooltip config}
\usage{
get_plotly_hover_config(bgcolor = "#ffffff", fontcolor = "#0c1f4a")
}
\arguments{
\item{bgcolor}{Tooltip background color.}

\item{fontcolor}{Tooltip text color.}
}
\value{
A list for \code{plotly::layout(hoverlabel = ...)}.
}
\description{
Plotly hover tooltip config
}
\keyword{internal}
