% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{show_preprocessing_required_modal}
\alias{show_preprocessing_required_modal}
\title{Show preprocessing-required modal}
\usage{
show_preprocessing_required_modal(
  message = "Please complete preprocessing steps first.",
  title = "Preprocessing Required"
)
}
\arguments{
\item{message}{Modal body message.}

\item{title}{Modal title.}
}
\value{
Invisibly \code{NULL}.
}
\description{
Show preprocessing-required modal
}
\keyword{internal}
