% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lexical_analysis.R
\name{plot_mwe_frequency}
\alias{plot_mwe_frequency}
\title{Plot Multi-Word Expression Frequency}
\usage{
plot_mwe_frequency(
  mwe_data,
  title = "Multi-Word Expression Frequency",
  color_by_source = TRUE,
  primary_color = "#10B981",
  secondary_color = "#A855F7",
  height = 500,
  width = NULL
)
}
\arguments{
\item{mwe_data}{Data frame containing MWE data with columns:
\itemize{
\item \code{feature}: The multi-word expression text
\item \code{frequency}: Frequency count
\item \code{rank}: (optional) Rank of the expression
\item \code{docfreq}: (optional) Document frequency
\item \code{source}: (optional) Source category (e.g., "Top 20", "Manual")
}}

\item{title}{Plot title (default: "Multi-Word Expression Frequency")}

\item{color_by_source}{Whether to color bars by source column (default: TRUE)}

\item{primary_color}{Color for primary/top expressions (default: "#10B981")}

\item{secondary_color}{Color for secondary/manual expressions (default: "#A855F7")}

\item{height}{Plot height in pixels (default: 500)}

\item{width}{Plot width in pixels (default: NULL for auto)}
}
\value{
A plotly object
}
\description{
Creates a bar plot showing multi-word expression frequencies with optional
source-based coloring to distinguish between detected and manually added expressions.
}
\concept{visualization}
