% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lexical_analysis.R
\name{get_sentences}
\alias{get_sentences}
\title{Get Sentences}
\usage{
get_sentences(x, model = "en_core_web_sm")
}
\arguments{
\item{x}{Character vector of texts OR a quanteda tokens object.}

\item{model}{Character; spaCy model to use (default: "en_core_web_sm").}
}
\value{
A data frame with sentence information.
}
\description{
Segment texts into sentences using spaCy's sentence boundary detection.
}
\concept{lexical}
