% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{show_dfm_required_modal}
\alias{show_dfm_required_modal}
\title{Show DFM-required modal}
\usage{
show_dfm_required_modal(
  feature_name = "this feature",
  additional_message = NULL
)
}
\arguments{
\item{feature_name}{Feature description in the message.}

\item{additional_message}{Optional extra context appended to the body.}
}
\value{
Invisibly \code{NULL}.
}
\description{
Show DFM-required modal
}
\keyword{internal}
