% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{create_aria_label}
\alias{create_aria_label}
\title{Generate ARIA Label}
\usage{
create_aria_label(element_type, action, context = NULL)
}
\arguments{
\item{element_type}{Type of element (e.g., "button", "input", "plot")}

\item{action}{Action or purpose (e.g., "analyze", "download", "visualize")}

\item{context}{Additional context (optional)}
}
\value{
Character string with ARIA label
}
\description{
Creates accessible ARIA label for UI elements.
}
\keyword{internal}
