% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/semantic_analysis.R
\name{export_document_clustering}
\alias{export_document_clustering}
\title{Export Document Clustering Analysis}
\usage{
export_document_clustering(
  coordinates,
  clusters = NULL,
  labels = NULL,
  doc_ids = NULL,
  file_path
)
}
\arguments{
\item{coordinates}{Document coordinates}

\item{clusters}{Cluster assignments (optional)}

\item{labels}{Cluster labels (optional)}

\item{doc_ids}{Document IDs}

\item{file_path}{Path to save the CSV file}
}
\value{
Invisible data frame of the exported data
}
\description{
Export document clustering analysis results to CSV
}
\concept{semantic}
