% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{log_security_event}
\alias{log_security_event}
\title{Log Security Event}
\usage{
log_security_event(event_type, details, session_info, level = "info")
}
\arguments{
\item{event_type}{Type of security event}

\item{details}{Additional details about the event}

\item{session_info}{Shiny session object}

\item{level}{Log level ("info", "warning", "error")}
}
\description{
Log Security Event
}
\keyword{internal}
